@@ -8,7 +8,9 @@ class MessageType(Enum):
     XML_ACK = 0000
     REQUEST_CONFIGURATION = 1
     SET_FILTER_SPEED = 9
+    SET_HEATER_COMMAND = 11
     REQUEST_LOG_CONFIG = 31
+    SET_SOLAR_SET_POINT_COMMAND = 40
     SET_HEATER_ENABLED = 147
     SET_EQUIPMENT = 164
     CREATE_SCHEDULE = 230
